import request from '@/utils/request'

// 查询银行转账列表
export function listTransfer(query) {
  return request({
    url: '/yinnong/transfer/list',
    method: 'get',
    params: query
  })
}
// 查询现金提现申请列表
export function listCash(query) {
  return request({
    url: '/yinnong/cash/list',
    method: 'get',
    params: query
  })
}
// 查询银行转账详细
export function getTransfer(id) {
  return request({
    url: '/yinnong/transfer/get/' + id,
    method: 'get'
  })
}

export function transactionStatusQuery(id) {
  return request({
    url: '/yinnong/transfer/transactionStatusQuery/' + id,
    method: 'get'
  })
}
export function reapply(id) {
  return request({
    url: '/yinnong/transfer/reapply/' + id,
    method: 'get'
  })
}
export function queryTransferDetail(transferId){
  return request({
    url: '/yinnong/transferDetail/getDetails/' + transferId,
    method: 'get'
  })
}

// 查询银行转账详细
export function getCash(id) {
  return request({
    url: '/yinnong/cash/get/' + id,
    method: 'get'
  })
}
// 查询其他申请详情列表
export function listCashdetailByCashId(id) {
  return request({
    url: '/yinnong/cashdetail/listCashdetailByCashId/'+id,
    method: 'get'
  })
}

export function listPayee(query) {
  return request({
    url: '/yinnong/payee/selectlist',
    method: 'get',
    params: query
  })
}

// 修改银行转账
export function updateTransfer(data) {
  return request({
    url: '/yinnong/transfer/edit',
    method: 'post',
    data: data
  })
}

// 修改现金提现申请
export function updateCash(data) {
  return request({
    url: '/yinnong/cash/edit',
    method: 'post',
    data: data
  })
}

// 查询工程项目关联关系详细
export function getProjectto(query) {
  return request({
    url: '/yinnong/project/getProjectto/',
    method: 'get',
    params: query
  })
}

// 查询工程项目列表
export function listProject(query) {
  return request({
    url: '/yinnong/project/list',
    method: 'get',
    params: query
  })
}
// 通过外部信息查询合同信息
export function getInfoto(query) {
  return request({
    url: '/contraction/info/selectInfoByOutId/',
    method: 'get',
    params: query
  })
}
// 新增工程项目关联关系
export function addProjectto(data) {
  return request({
    url: '/yinnong/project/addProjectto',
    method: 'post',
    data: data
  })
}
// 新增关联合同
export function addInfoto(data) {
  return request({
    url: '/contraction/info/relationAdd',
    method: 'post',
    data: data
  })
}
// 提交审批
export function customSubmit(id) {
  return request({
    url: '/yinnong/transfer/customSubmit/' + id,
    method: 'post'
  })
}

// 提交线下审批
export function offlineCustomSubmit(id) {
  return request({
    url: '/yinnong/transfer/offlineCustomSubmit/' + id,
    method: 'post'
  })
}

// 现金提交审批
export function cashSubmit(id) {
  return request({
    url: '/yinnong/cash/customSubmit/' + id,
    method: 'post'
  })
}

// 线下提交审批
export function offlineCashSubmit(id) {
  return request({
    url: '/yinnong/cash/offlineCustomSubmit/' + id,
    method: 'post'
  })
}

// 删除现金提现申请
export function delCash(id) {
  return request({
    url: '/yinnong/cash/remove/' + id,
    method: 'get'
  })
}
// 新增银行转账
export function addTransfer(data) {
  return request({
    url: '/yinnong/transfer/add',
    method: 'post',
    data: data
  })
}

// 新增现金提现申请
export function addCash(data) {
  return request({
    url: '/yinnong/cash/add',
    method: 'post',
    data: data
  })
}

// 新增其他申请详情
export function addCashdetail(data) {
  return request({
    url: '/yinnong/cashdetail/add',
    method: 'post',
    data: data
  })
}

// 查询转账账户详情详细
export function getTransferProcess(id) {
  return request({
    url: '/yinnong/transfer/getProcessSchedule/' + id,
    method: 'get'
  })
}

// 查询转账账户详情详细
export function getCashProcess(id) {
  return request({
    url: '/yinnong/cash/getProcessSchedule/' + id,
    method: 'get'
  })
}

export function getAccount(query){
  return request({
    url: '/cashier/account/list',
    method: 'get',
    params: query
  })
}

// 查询当前账期余额
export function getQmyeFlow(id) {
  return request({
    url: '/cashier/flow/getQmye/' + id,
    method: 'post'
  })
}

// 查询当前账期余额
export function approval(data) {
  return request({
    url: '/activiti/process/complete',
    method: 'post',
    params:data
  })
}

// 上传附件
export function attach(data) {
  return request({
    url: '/common/attach',
    method: 'post',
    data:data
  })
}
// 删除银行转账
export function delTransfer(id) {
  return request({
    url: '/yinnong/transfer/remove/' + id,
    method: 'get'
  })
}

// 查询村级账户列表
export function listVaccount(query) {
  return request({
    url: '/yinnong/vaccount/list',
    method: 'get',
    params: query
  })
}
// 查询村级账户列表
export function listVaccount1(query) {
  return request({
    url: '/yinnong/vaccount/list1',
    method: 'get',
    params: query
  })
}
// 查询乡镇账户列表
export function listTaccount(query) {
  return request({
    url: '/yinnong/taccount/list',
    method: 'get',
    params: query
  })
}

// 查询银行汇票列表
export function listMoneyorder(query) {
  return request({
    url: '/yinnong/moneyorder/list',
    method: 'get',
    params: query
  })
}

//上传全局方法附件

export function commonAttach(data) {
  return request({
    url: '/common/attach',
    method: 'post',
    header: { "Content-Type": 'application/x-www-form-urlencoded' },
    data: data
  })
}
//查询已上传附件
export const attachmentList = (data) => {
  return request({
    url: '/system/attachment/query',
    method: 'get',
    params: data
  })
}
//删除已上传附件
export function systemAttachment(ids) {
  if (ids != undefined) {
    return request({
      url: '/system/attachment/remove/' + ids,
      method: 'get'
    })
  }
}
// 查询转账账户详情详细
export function getTransferProcess1(id) {
  return request({
    url: '/yinnong/cash/getProcessSchedule/' + id,
    method: 'get'
  })
}

// 查询出纳账户设置列表
export function listAccount(query) {
  return request({
    url: '/cashier/account/list',
    method: 'get',
    params: query
  })
}

// 查询村虚拟出纳账户设置列表
export function listAccount1(query) {
  return request({
    url: '/cashier/account/listFoBalance',
    method: 'get',
    params: query
  })
}
// 查询合同信息列表
export function listInfo(query) {
  return request({
    url: '/contraction/info/list',
    method: 'get',
    params: query
  })
}
// 查询审批模板列表
export function listTemplate(query) {
  return request({
    url: '/service/template/list',
    method: 'get',
    params: query
  })
}
// 根据模板主表id审批模板明细详细
export function selectApprovalByTemplateId(templateId) {
  return request({
    url: '/service/templateDetail/selectApprovalByTemplateId/' + templateId,
    method: 'get'
  })
}

// 撤回
export function updateTYinnongTransferFoStatus(data) {
  return request({
    url: '/yinnong/transfer/updateTYinnongTransferFoStatus',
    method: 'post',
    data: data
  })
}

// 查询重大事项申请列表
export function listMajorevent(query) {
  return request({
    url: '/yinnong/majorevent/list',
    method: 'get',
    params: query
  })
}

// 新增重大事项申请
export function addMajorevent(data) {
  return request({
    url: '/yinnong/majorevent/add',
    method: 'post',
    data: data
  })
}

// 提交审批
export function customSubmitMajorevent(id) {
  return request({
    url: '/yinnong/majorevent/customSubmit/' + id,
    method: 'post'
  })
}
// 查询重大事项申请详细
export function getMajorevent(id) {
  return request({
    url: '/yinnong/majorevent/get/' + id,
    method: 'get'
  })
}

// 修改重大事项申请
export function updateMajorevent(data) {
  return request({
    url: '/yinnong/majorevent/edit',
    method: 'post',
    data: data
  })
}

// 删除重大事项申请
export function delMajorevent(id) {
  return request({
    url: '/yinnong/majorevent/remove/' + id,
    method: 'get'
  })
}

